//
//
// C++ Interface: $MODULE$
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KMFGENERICINTERFACEICMP_H
#define KMFGENERICINTERFACEICMP_H

#include <kmyfirewallgenericinterfaceicmp.h>

// QT Includes
#include <qguardedptr.h>

/**
@author Christian Hubinger
*/
namespace KMF {
class KMFGenericDoc;
class KMFNetwork;
class NetfilterObject;

class KMFGenericInterfaceIcmp : public KMyFirewallGenericInterfaceIcmp {
	Q_OBJECT
public:
	KMFGenericInterfaceIcmp( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );

	~KMFGenericInterfaceIcmp();

void loadDoc( KMFNetwork* doc );

public slots:
	void slotUpdateView();
	void slotUpdateView( NetfilterObject* );

private slots:
	void slotEnablePingReplyToggled( bool );
	void slotEnablePingReplyLimitToggled( bool );

private:
	QGuardedPtr<KMFNetwork> m_doc;	
};
}
#endif
